@@ -5,7 +5,7 @@ from gql import Client
 from gql.transport.requests import RequestsHTTPTransport
 from loguru import logger
 
-from .utils.ut_core import Utils
+from .utils.ut import Utils
 from .utils.ut_autprog import AutProgUtils
 
 class Schedule():
@@ -268,7 +268,8 @@ class Automation():
         df = pd.json_normalize(result['workflows'])
         return df
 
-    def workflowInstances(self, workflowId:str=None, showTasks=False) -> pd.DataFrame:
+    def workflowInstances(self, workflowId:str=None, fromTimepoint:str=None, toTimepoint:str=None, 
+        fields:list=None, where:str=None, showTasks=False) -> pd.DataFrame:
         """Shows Instances of a workflow. If workflowId=None, all Instances of all 
         workflows will be returned."""
 
@@ -280,6 +281,39 @@ class Automation():
         else:
             _workflowId = ''
 
+        if fromTimepoint != None:
+            _fromTimepoint = f'from: "{fromTimepoint}"'
+        else: 
+            _fromTimepoint = ''
+
+        if toTimepoint != None:
+            _toTimepoint = f'from: "{toTimepoint}"'
+        else: 
+            _toTimepoint = ''
+
+        if fields != None:
+            if type(fields) != list:
+                fields = [fields]
+            _fields = Utils._queryFields(fields, recursive=True)   
+        else:
+            _fields =f'''
+                id
+                name
+                businessKey
+                version
+                startTime
+                endTime
+                state
+                variables {{
+                    name
+                    value
+                    time
+                }}''' 
+
+        resolvedFilter = ''
+        if where != None: 
+            resolvedFilter = Utils._resolveWhereString(where)
+
         if showTasks != False:
             _tasks = f'''tasks {{
                             id
@@ -294,19 +328,8 @@ class Automation():
             _tasks = ''
 
         graphQLString = f'''query Instances {{
-            {key}({_workflowId}, all:true) {{
-                id
-                name
-                businessKey
-                version
-                startTime
-                endTime
-                state
-                variables {{
-                    name
-                    value
-                    time
-                }}
+            {key}({_workflowId}, {_fromTimepoint}, {_toTimepoint}, {resolvedFilter}, all:true) {{
+                {_fields}
                 {_tasks}
                 }}
             }}
@@ -317,10 +340,12 @@ class Automation():
 
         if showTasks != False:
             df = pd.json_normalize(result[key], meta=meta, record_path=['tasks'], record_prefix='task.', errors='ignore')
-            df = df.sort_values(by='startTime', ascending=False)
+            if 'startTime' in df.columns:
+                df = df.sort_values(by='startTime', ascending=False)
         else:
             df = pd.json_normalize(result[key])
-            df = df.sort_values(by='startTime', ascending=False)
+            if 'startTime' in df.columns:
+                df = df.sort_values(by='startTime', ascending=False)
         return df
     
     def createWorkflow(self, id, name, description:str=None):
