@@ -3,13 +3,11 @@ from gql.transport.requests import RequestsHTTPTransport
 from loguru import logger
 import base64
 
-import pandas
+import pandas as pd
 import sys
 import json
 import os
 import requests
-import pytz
-from tzlocal import get_localzone
 import getpass
 
 from .fileimport import FileImport
@@ -165,7 +163,7 @@ class TechStack(Utils, Meta):
         return
 
     def inventories(self, fields:list=None, where:str=None, orderBy:str=None, 
-        asc:bool=True) -> pandas.DataFrame:
+        asc:bool=True) -> pd.DataFrame:
         """
         Returns a DataFrame of existing inventories.
 
@@ -220,12 +218,22 @@ class TechStack(Utils, Meta):
         result = Utils._executeGraphQL(self, graphQLString)
         if result == None: return
 
-        df = pandas.json_normalize(result['inventories'])
+        df = pd.json_normalize(result['inventories'])
         return df
 
-    def items(self, inventoryName:str, references:bool=False, fields:list=None, where:str=None, 
-        orderBy:str=None, asc:bool=True, pageSize:int=5000, 
-        arrayPropertiesToPage:list=None, arrayPageSize:int=50) -> pandas.DataFrame:
+    def items(
+        self, 
+        inventoryName:str, 
+        references:bool=False, 
+        fields:list=None, 
+        where:str=None, 
+        orderBy:str=None, 
+        asc:bool=True, 
+        pageSize:int=5000, 
+        arrayPropertiesToPage:list=None, 
+        arrayPageSize:int=50,
+        top:int=100000,
+        ) -> pd.DataFrame:
         """
         Returns items of an inventory in a DataFrame.
 
@@ -255,6 +263,8 @@ class TechStack(Utils, Meta):
             not yet supported. The properties listed here will just make use of of the arrayPageSize.
         arrayPageSize: int = 50
             The page size of list items that is used to page list items in an inventory item.
+        top: int = None
+            Returns a restricted set of items oriented at the latest entries.
 
         Example:
         --------
@@ -300,9 +310,18 @@ class TechStack(Utils, Meta):
 
         result = []
         count = 0
+        stop = False
         lastId = ''
 
         while True:
+
+            # Handling top (premature stop)
+            if top != None:
+                loadedItems = pageSize * count
+                if top - loadedItems < pageSize:
+                    stop = True
+                    pageSize = top - loadedItems
+
             graphQLString= f''' query getItems {{
                     {inventoryName} (
                             pageSize: {pageSize} 
@@ -328,7 +347,7 @@ class TechStack(Utils, Meta):
                 _result = self.client.execute(query)
             except Exception as err:
                 logger.error(err)
-                return
+                return         
             
             if _result[inventoryName]:
                 result += _result[inventoryName]
@@ -339,7 +358,9 @@ class TechStack(Utils, Meta):
             except: 
                 break
 
-        df = pandas.json_normalize(result)
+            if stop == True: break
+
+        df = pd.json_normalize(result)
         
         if fields != None: #sorts dataframe according to given fields
             try: # for array field this does not work
@@ -398,7 +419,7 @@ class TechStack(Utils, Meta):
         result = Utils._executeGraphQL(self, graphQLString)
         if result == None: return
 
-        df = pandas.json_normalize(result['inventory']['properties'])
+        df = pd.json_normalize(result['inventory']['properties'])
 
         if namesOnly == True:
             return list(df['name'])
@@ -422,7 +443,7 @@ class TechStack(Utils, Meta):
 
         Example:
         --------
-        >>> inventoryList('appartments') 
+        >>> propertyList('appartments') 
 
         """
 
@@ -431,10 +452,57 @@ class TechStack(Utils, Meta):
         if dataTypes == False:
             properties = Utils._propertyList(_properties, recursive=references)
         else:
-            properties = pandas.Series(Utils._propertyTypes(_properties))
+            properties = pd.Series(Utils._propertyTypes(_properties))
 
         return properties
 
+    def filterValues(self, inventoryName:str, top:int=10000) -> pd.DataFrame:
+        """
+        Returns a DataFrame of values that can be used in a where-string. 
+        Only string data types are returned. 
+
+        Parameters:
+        ----------
+        inventoryName : str
+            The name of the inventory.
+        top: int = None
+            Uses a restricted set of items oriented at the latest entries to 
+            provide a value set.
+
+        Example:
+        --------
+        >>> filterValues('appartments') 
+
+        """
+        properties = self.propertyList(inventoryName, dataTypes=True)
+
+        propertyList = []
+        for property, dataType in zip(properties.index, properties):
+            if 'sys_' in property: continue
+            if dataType != 'String': continue
+            propertyList.append(property)
+
+        df = self.items(inventoryName, fields=propertyList, top=top)
+
+        logger.debug(f"Used columns: {df.columns}")
+        logger.debug(f"PropertyList: {propertyList}")
+
+        propertyValues = {}
+        for property in propertyList:
+            if 'sys_' in property: continue
+            if len(set(df[property])) == len(df): continue
+            propertySet = set(df[property])
+            logger.debug(f"PropertySet: {propertySet}")
+            try:
+                propertySet.remove(None)
+            except: pass
+            propertyValues.setdefault(df[property].name, sorted(list(propertySet)))
+
+
+        valuesDf = pd.DataFrame.from_dict(propertyValues, orient='index').T
+        valuesDf.fillna(value='-', inplace=True)
+        return valuesDf
+
     def addItems(self, inventoryName:str, items:list) -> str:
         """
         Adds from a list of dicts new items and returns a list
@@ -681,7 +749,7 @@ class TechStack(Utils, Meta):
                 logger.info(f"Inventory '{inventoryName}' deleted.")
         else: return
 
-    def variants(self) -> pandas.DataFrame:
+    def variants(self) -> pd.DataFrame:
         """
             Returns a dataframe of available variants.
         """
@@ -697,7 +765,7 @@ class TechStack(Utils, Meta):
         result = Utils._executeGraphQL(self, graphQLString)
         if result == None: return
 
-        df = pandas.json_normalize(result[key])
+        df = pd.json_normalize(result[key])
         return df
 
     def clearInventory(self, inventoryName:str, force=False):
@@ -757,16 +825,13 @@ class TechStack(Utils, Meta):
 
         Parameters:
         -----------
-        inventoryName : str
+        inventoryName: str
             The name of the inventory.
-        items : list
+        inventoryItemIds: list = None
             A list of inventoryItemIds that should be deleted.
-        where : str
+        where: str = None
             Filter criteria to select items that should be deleted.
-            Referenced items are not supported.
-        all : bool
-            All items of the inventory will be deleted
-        force : bool
+        force: bool = False
             Use True to ignore confirmation.
 
         Examples:
@@ -812,7 +877,6 @@ class TechStack(Utils, Meta):
                 }}
             }}
             '''
-        
 
         if force == True: confirm = 'y'
         if confirm == 'y':
@@ -868,19 +932,21 @@ class TechStack(Utils, Meta):
 
         Parameters:
         -----------
-        inventoryName : str
+        inventoryName: str
             The name of the inventory where the item is located.
-        inventoryItemId : str
+        inventoryItemId: str
             The sys_inventoryItemId of the item.
-        arrayProperty : str
+        arrayProperty: str
             The name of the property whose array items are to be updated.
-        operation : str
+        operation: str
             The update operation to be performed. Options:
             insert: inserts a list of array items.
             removeById: removes array items by a list of given ids.
             removeByIndex: removes array items by a list of given indices.
             removeAll: removes all array items
-        cascadeDelete : bool (False)
+        arrayItems: list = None
+            A list of indices or item Ids
+        cascadeDelete: bool = False
             If array items are refencences, True will delete also the reference items. 
 
         Examples:
@@ -897,7 +963,7 @@ class TechStack(Utils, Meta):
 
         if operation == 'removeAll':
             try:
-                propertyDf = TechStack.inventoryProperties(self, 'volueGroups')
+                propertyDf = TechStack.inventoryProperties(self, inventoryName)
                 arrayProps = propertyDf[propertyDf['name'] == arrayProperty]
                 logger.debug(f"Properties of array: {arrayProps}")
                 if arrayProps['type'].item() == 'reference':
@@ -1031,8 +1097,8 @@ class TechStack(Utils, Meta):
     
     def defaultDataFrame(self, maxRows, maxColumns):
         """Sets default sizes for a DataFrame for the current session"""
-        pandas.options.display.max_rows = maxRows
-        pandas.options.display.max_columns = maxColumns
+        pd.options.display.max_rows = maxRows
+        pd.options.display.max_columns = maxColumns
         return
 
     def defaults(self):
