@@ -470,18 +470,21 @@ class FileImport():
 
         Parameters:
         -----------
-        filePath : str
+        filePath: str
             The file path of the csv file that should be imported.
-        groupInventoryName : str
+        groupInventoryName: str
             The field name of the group inventory.
-        instanceInventoryName : str
+        instanceInventoryName: str
             The field name of the time series instance inventory belonging to the group.
-        delimiter : str = ','
+        importKeyProperty: str
+            Provide a property of the parent group time series that is unique.
+            (The first column 'groupName' used in the CSV file.)
+        delimiter: str = ','
             The CSV delimiter. Choose ',', ';', or 'tab'.
-        chunkSize : int
+        chunkSize: int = 500
             Determines the number of items which are written per chunk. Using chunks
             can be necessary to avoid overloading.
-        pause : int
+        pause: int = 1
             Between each chunk upload a pause is inserted in order to avoid overloading.
 
         """
