@@ -6,7 +6,7 @@ from gql.transport.requests import RequestsHTTPTransport
 from loguru import logger
 
 from .utils.ut_autprog import AutProgUtils
-from .utils.ut_core import Utils
+from .utils.ut import Utils
 
 class Programming():
 
@@ -40,7 +40,8 @@ class Programming():
         return df
 
     def createFunction(self, name:str, languageVersion:str, description:str=None, 
-        files:list=None, deploy:bool=False, deploymentName:str=None, envVars:dict=None) -> str:
+        files:list=None, deploy:bool=False, deploymentName:str=None, envVars:dict=None,
+        memoryLimit:str='250M', cpuLimit:float=0.2) -> str:
         """ 
         Creates a function with possibility to commit files and deployment
         in one step. The function Id is returned.
@@ -114,11 +115,11 @@ class Programming():
             else:
                 if deploymentName == None:
                     deploymentName = name.lower()
-                self.deployFunction(functionId, deploymentName, envVars)
+                self.deployFunction(functionId, deploymentName, envVars, memoryLimit, cpuLimit)
                 return functionId
 
     def commitFunctionFiles(self, functionId:str, files:list=None, deploy:bool=False, 
-        deploymentName:str=None, envVars:dict=None) -> None:
+        deploymentName:str=None, envVars:dict=None, memoryLimit:str='250M', cpuLimit:float=0.2) -> None:
         """
         Upload programming files to an existing function. 
 
@@ -135,6 +136,12 @@ class Programming():
         envVars : dict
             A Dictionary of Environment variables provided to the deployment function. All values
             will be converted to string.
+        memoryLimit: str = '250M'
+            The memory that is assigned for execution of this function. 
+        cpuLimit: loat = 0.2
+            The assigned amount of CPU capacity to this function: note, that a too high capacity
+            might affect other services negatively.
+
 
         Example:
         --------
@@ -173,22 +180,28 @@ class Programming():
             else:
                 if deploymentName == None:
                     logger.error(f"No deployment name was provided for deployment. Function id: {functionId}")
-                self.deployFunction(functionId, deploymentName, envVars)
+                self.deployFunction(functionId, deploymentName, envVars, memoryLimit, cpuLimit)
 
         return result
 
-    def deployFunction(self, functionId:str, deploymentName:str, envVars:dict=None):
+    def deployFunction(self, functionId:str, deploymentName:str, envVars:dict=None,
+        memoryLimit:str='250M', cpuLimit:float=0.2):
         """
         Deploys a function to make it executable.
 
         Parameters:
         ----------
-        functionId : str
+        functionId: str
             Id of an existing function.
         deploymentName:
             The name of the deployed function. Use small letters only and no special characters.
-        envVars : dict
+        envVars: dict = None
             A Dictionary of Environment variables provided to the deployment function. 
+        memoryLimit: str = '250M'
+            The memory that is assigned for execution of this function.   
+        cpuLimit: loat = 0.2
+            The assigned amount of CPU capacity to this function: note, that a too high capacity
+            might affect other services negatively.
 
         Example:
         --------
@@ -207,6 +220,8 @@ class Programming():
                 input: {{
                 functionId: "{functionId}"
                 functionName: "{deploymentName}"
+                memoryLimit: "{memoryLimit}"
+                cpuLimit: "{str(cpuLimit)}"
                 {_vars}
                 }}
             ) {{
