@@ -255,7 +255,7 @@ class TimeSeries():
 
         return
 
-    def setTimeSeriesDataCollection(self, timeSeriesData:list, chunkSize:int=1000) -> None:
+    def setTimeSeriesDataCollection(self, timeSeriesData:list, chunkSize:int=10000) -> None:
         """
         Sets new time series data (timestamp & value) to an existing time series or 
         overwrites existing values. The sys_inventoryId and sys_inventoryItemId of the 
@@ -445,6 +445,9 @@ class TimeSeries():
 
         if displayMode == 'pivot':
             df = df.pivot_table(index='timestamp', columns=fields, values='value', dropna=True)
+            if len(df.columns) == 0:
+                logger.warning(f"No display value found. Provide at least 1 property for argument 'fields'.")
+                return
             df.index = pd.to_datetime(df.index, format='%Y-%m-%dT%H:%M:%S').tz_convert(pytz.timezone(tz))
             if Utils.useDateTimeOffset == False:
                 df.index = df.index.tz_localize(tz=None)
@@ -457,6 +460,9 @@ class TimeSeries():
 
         elif displayMode == 'pivot-full':
             df = df.pivot_table(index='timestamp', columns=fields, values='value', dropna=False)
+            if len(df.columns) == 0:
+                logger.warning(f"No display value found. Provide at least 1 property for argument 'fields'.")
+                return
             df.index = pd.to_datetime(df.index, format='%Y-%m-%dT%H:%M:%S').tz_convert(pytz.timezone(tz))
             if Utils.useDateTimeOffset == False:
                 df.index = df.index.tz_localize(tz=None)
@@ -635,8 +641,19 @@ class TimeSeries():
         result = Utils._executeGraphQL(self, graphQLString)
         if result == None: return
 
-        meta = [field for field in fields]
-        meta += [['timeSeriesInstance', field] for field in instanceFields]
+
+        meta = []
+        if type(fields) != list:
+            meta.append(fields)
+        else:
+            for field in fields:
+                meta.append(field)
+
+        if type(instanceFields) != list:
+            meta.append(['timeSeriesInstances', instanceFields])
+        else:
+            for field in instanceFields:
+                meta.append(['timeSeriesInstance', field])
 
         df = pd.json_normalize(result[key], record_path = ['timeSeriesInstances', '_dataPoints'], 
             meta=meta)
@@ -658,6 +675,9 @@ class TimeSeries():
 
         if displayMode == 'pivot':
             df = df.pivot_table(index='timestamp', columns=pivotColumns, values='value', dropna=True)
+            if len(df.columns) == 0:
+                logger.warning(f"No display value found. Provide at least 1 property for argument 'fields'.")
+                return
             df.index = pd.to_datetime(df.index, format='%Y-%m-%dT%H:%M:%S').tz_convert(pytz.timezone(tz))
             if Utils.useDateTimeOffset == False:
                 df.index = df.index.tz_localize(tz=None)
@@ -670,6 +690,9 @@ class TimeSeries():
 
         elif displayMode == 'pivot-full':
             df = df.pivot_table(index='timestamp', columns=pivotColumns, values='value', dropna=False)
+            if len(df.columns) == 0:
+                logger.warning(f"No display value found. Provide at least 1 property for argument 'fields'.")
+                return
             df.index = pd.to_datetime(df.index, format='%Y-%m-%dT%H:%M:%S').tz_convert(pytz.timezone(tz))
             if Utils.useDateTimeOffset == False:
                 df.index = df.index.tz_localize(tz=None)
@@ -859,6 +882,9 @@ class TimeSeries():
                 logger.info(f"The query did not fetch any time series values")
                 return
             df = df.pivot_table(index='timestamp', columns=pivotColumns, values='value', dropna=False)
+            if len(df.columns) == 0:
+                logger.info(f"The resulting DataFrame is emmpty.")
+                return
             df.index = pd.to_datetime(df.index, format='%Y-%m-%dT%H:%M:%S').tz_convert(pytz.timezone(tz))
             if Utils.useDateTimeOffset == False:
                 df.index = df.index.tz_localize(tz=None)
@@ -873,6 +899,9 @@ class TimeSeries():
                 logger.info(f"The query did not fetch any time series values")
                 return
             df = df.pivot_table(index='timestamp', columns=pivotColumns, values='value', dropna=True)
+            if len(df.columns) == 0:
+                logger.info(f"The resulting DataFrame is emmpty.")
+                return
             df.index = pd.to_datetime(df.index, format='%Y-%m-%dT%H:%M:%S')#.tz_convert(pytz.timezone(tz))
             if Utils.useDateTimeOffset == False:
                 df.index = df.index.tz_localize(tz=None)
@@ -894,9 +923,123 @@ class TimeSeries():
             return
        
 
-    def deleteTimeSeriesRange(self, inventoryName:str, inventoryItemIds:list, fromTimepoint:str,
-        toTimepoint:str, force:bool=False) -> None:
-        pass
+    def deleteTimeSeriesData(
+        self,
+        inventoryName:str, 
+        fromTimepoint:str,
+        toTimepoint:str, 
+        inventoryItemIds:list=None, 
+        where:str=None,
+        timeZone:str=None,
+        force:bool=False) -> None:
+
+        """
+        Deletes time series data for a specified time range for multiple time series within an inventory.
+
+        Parameters:
+        -----------
+        inventoryName: str
+            The name of the inventory.
+        fromTimepoint: str
+            The starting timepoint from where time series data will be deleted. Different string
+            formats as well as datetime.datetime and pandas.Timestamp objects are supported.
+        toTimepoint: str
+            The end of the time range up until time series values will be deleted.
+        inventoryItemIds: list = None
+            A list of inventoryItemIds that should be deleted.
+        where: str = None
+            Filter criteria to select items that should be deleted.
+        timeZone: str = None
+            A time zone provided in IANA or isoformat (e.g. 'Europe/Berlin' or 'CET'). Defaults
+            to the local time zone or to a previously set default time zone.
+        force: bool = False
+            Use True to ignore confirmation.
+        """
+
+        def createDataPoints(fromTimepoint, toTimepoint, timeUnit, factor) -> list:
+            unitMapping = {
+                'MILLISECOND':'ms',
+                'SECOND':'S',
+                'MINUTE':'min',
+                'HOUR':'H',
+                'DAY':'D',
+                'WEEK':'W',
+                'MONTH':'M',
+                'YEAR':'YS'
+            }
+            freq = f'{factor}{unitMapping[timeUnit]}'
+            index = pd.date_range(fromTimepoint, toTimepoint, freq=freq)
+            logger.debug(f"DateTimeIndex: {index}")
+
+            dataPoints = []
+            for timepoint in index:
+                data = {
+                    'timestamp': timepoint,
+                    'value': 0,
+                    'flag':'MISSING'
+                }
+                dataPoints.append(data)
+            
+            return dataPoints
+
+        if timeZone != None:
+            tz = timeZone
+        else:
+            tz = Utils.timeZone          
+
+        fromTimepoint = TimeUtils._inputTimestamp(fromTimepoint, tz)
+        toTimepoint = TimeUtils._inputTimestamp(toTimepoint, tz)
+
+        inventory = coreClient.inventories(where=f'name eq "{inventoryName}"')
+        sys_inventoryId = inventory.loc[0, 'inventoryId']
+
+        if inventoryItemIds == None and where == None:
+            logger.error(f"No id list of items and no where-criteria were provided.")
+        if inventoryItemIds != None and where != None:
+            logger.warning(f"List of items and where-criteria has been provided. Item list is used.")
+
+        if where != None:
+            df = coreClient.items(inventoryName, fields=['sys_inventoryItemId','resolution'], where=where)
+            if df.empty:
+                logger.info(f"The where criteria '{where}' led to no results.")
+                return
+            
+        if inventoryItemIds != None:
+            idList = '['
+            for item in inventoryItemIds:
+                idList += f'"{item}", '
+            idList += ']'
+            df = coreClient.items(inventoryName, fields=['sys_inventoryItemId','resolution'], where=f'sys_inventoryItemId in {idList}')
+
+        if force == True:
+            confirm = 'y'
+        else:
+            confirm = input(f"Press 'y' to delete values for {len(df)} time series items: ")
+        if confirm != 'y':
+            return
+
+        for ts in df.iterrows():
+
+            sys_inventoryItemId = ts[1]['sys_inventoryItemId']
+            timeUnit = ts[1]['resolution'].split(' ')[1]
+            factor = ts[1]['resolution'].split(' ')[0]
+            dataPoints = createDataPoints(fromTimepoint, toTimepoint, timeUnit, factor)
+            resolution = {'timeUnit':timeUnit, 'factor':factor}
+
+            timeSeries = [{
+                'sys_inventoryId': sys_inventoryId,
+                'sys_inventoryItemId': sys_inventoryItemId,
+                'data':
+                    {
+                    'resolution': resolution,
+                    'dataPoints': dataPoints
+                    }
+                }]
+
+            self.setTimeSeriesDataCollection(timeSeries)
+        logger.info(f"Deleted values for {len(df)} time series items")
+
+        return
 
     def timeSeriesItems(self, inventoryName:str, references:bool=False, fields:list=None, where:str=None, 
         orderBy:str=None, asc:bool=True, pageSize:int=5000, 
