@@ -195,7 +195,7 @@ class Utils():
         
         _properties = '[\n'
         for property in properties:
-            _properties += f'{{_groupInventoryItemId: "{groupItemId}"\n'
+            _properties += f'{{sys_groupInventoryItemId: "{groupItemId}"\n'
             for key, value in property.items():
                 _properties += Utils._customProperties(key, value)      
             
@@ -258,7 +258,7 @@ class Utils():
         """
         
         types = ['Boolean', 'String', 'DateTime', 'DateTimeOffset', 'Int', 'Long', 'Decimal', None]
-        systemProperties = ['id', '_revision', '_propertyPermissions'] #'_inventoryItemId','_displayValue', 
+        systemProperties = ['id', '_revision', '_propertyPermissions'] 
         properties = {}
         _scheme = self.scheme['__schema']['types']
 
@@ -294,7 +294,7 @@ class Utils():
                             if recursive == True:
                                 logger.debug("Recursive")
                                 if property['type']['kind'] =='LIST':
-                                    properties.setdefault(property['name'], {'_inventoryItemId': 'String'})
+                                    properties.setdefault(property['name'], {'sys_inventoryItemId': 'String'})
                                 else:
                                     properties.setdefault(property['name'], makeDict(property['type']['name']))
                             else:
