@@ -163,7 +163,7 @@ class FileUtils(UtilsProperty):
                         continue
                 else:
                     groupInventoryItemId = content[i][0]
-                item = {'_groupInventoryItemId':groupInventoryItemId}
+                item = {'sys_groupInventoryItemId':groupInventoryItemId}
                 for j, field in enumerate(row):
                     if j == 0: continue
                         
