@@ -22,7 +22,7 @@ class UtilsTimeSeries():
                         elif dkey == 'dataPoints':
                             tsData += '    dataPoints: [\n'
                             for dp_key in dvalue:
-                                if 'flag' not in dvalue:
+                                if 'flag' not in dp_key:
                                     tsData += f'''     {{timestamp: "{dp_key['timestamp']}", value: {dp_key['value']}}}\n'''
                                 else:    
                                     tsData += f'''     {{timestamp: "{dp_key['timestamp']}", value: {dp_key['value']}, flag: {dp_key['flag']}}}\n'''
